import requests
from requests_toolbelt import MultipartEncoder

import inforion.ionapi.model.inforlogin as inforlogin
import logging as log
import json


def get_messaging_ping():
    url = inforlogin.base_url() + '/IONSERVICES/api/ion/messaging/service/ping'
    headers = inforlogin.header()
    res = requests.get(url, headers=headers)
    log.info('messaging ping: {}'.format(res.content))
    return res


def post_messaging_v2_multipart_message(parameter_request, message_payload):
    url = inforlogin.base_url() + '/IONSERVICES/api/ion/messaging/service/v2/multipartMessage'
    data = MultipartEncoder(
        fields={'ParameterRequest': ('filename', json.dumps(parameter_request), 'application/json'),
                'MessagePayload': ('filename', message_payload, 'application/octet-stream')
                }
    )
    headers = inforlogin.header()
    headers.update({'Content-Type': data.content_type})

    res = requests.post(url, headers=headers, data=data)
    log.info('messaging v2 multipart message: {}'.format(res.content))

    return res





import os
import sys

import pandas as pd

def checkfiletype(filepath):

    # Split the extension from the path and normalise it to lowercase.
    ext = os.path.splitext(filepath)[-1].lower()


    if ext == ".csv" or ext == ".xlsx" or ext == ".xls":
        return ext
    else:
        print ("Type is not supported")
        sys.exit(0)
    
    

def loadfile(file):

    ext = checkfiletype(file)
    
    if ext == ".csv":
        df = pd.read_csv(file)
    elif ext == ".xlsx" or ext == ".xls":
        df = pd.read_excel(file)
    return df

def savetodisk(file,df):

    ext = checkfiletype(file)

    if ext == ".csv":
        df.to_csv(file)
    else:

        writer = pd.ExcelWriter(file, engine='xlsxwriter')
        df.to_excel(writer, sheet_name='Log Output',index=False)
        writer.save()

def getDataFrame(inputfile):
    ext = checkfiletype(inputfile)
    df = loadfile(ext,inputfile)
    return df


                


import json
import os
import xlsxwriter
import openpyxl
import shutil

path = os.path.abspath(__file__)
dir_path = os.path.dirname(path)

apiDirPath = dir_path + "/api-files"
templateFileName = dir_path + "/Mapping_Template.xlsx"

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'


def getAPIFile(api_name):
    files = os.listdir(apiDirPath)
    for filename in files:
        file_path = os.path.join(apiDirPath, filename)
        with open(file_path) as json_file:
            data = json.load(json_file)
            file_api_name = data['info']['title'].split()[0]
            if file_api_name.startswith(api_name):
                return file_api_name, file_path


def getParametersList(filepath):
    parameters_list = {}
    with open(filepath) as json_file:
        data = json.load(json_file)
        for (k, v) in data['paths'].items():
            key = k.replace("/", "")
            if key.startswith('Add') or key.startswith('Chg') or key.startswith('Crt'):
                for jparam in v['get']['parameters']:
                    if jparam['name'].upper() not in parameters_list:
                        org_description = jparam['description']
                        ind = org_description.rfind('(')

                        jparam['api'] = key
                        if ind >= 0:
                            jparam['description'] = org_description[0:ind]
                            jparam['length'] = org_description[ind + 1:-1]
                        else:
                            jparam['description'] = org_description
                            jparam['length'] = ''

                        parameters_list[jparam['name'].upper()] = jparam

    #print(parameters_list)
    return parameters_list


def copyTemplateFile(outputfilename):
    filename = outputfilename
    if(not outputfilename.endswith('.xlsx')):
        filename = filename + '.xlsx'
    return shutil.copy(templateFileName,filename)

def checkIfTemplateFileExists():
    return os.path.isfile(templateFileName)


def getTypeCode(type_str):
    if type_str == 'string':
        return 'A'
    elif type_str == 'number':
        return 'N'
    elif type_str == 'date':
        return 'D'


def updateSheetWithData(filename, apiName, params):
    xfile = openpyxl.load_workbook(filename)

    #sheet = xfile.get_sheet_by_name('Mapping Template')
    sheet = xfile['Mapping Template']

    current_row = 11
    for k, v in params.items():
        # Serial Number
        sheet['A' + str(current_row)] = current_row - 10
        sheet['B' + str(current_row)] = apiName

        sheet['P' + str(current_row)] = k
        sheet['Q' + str(current_row)] = apiName
        sheet['R' + str(current_row)] = v['api']
        sheet['S' + str(current_row)] = getTypeCode(v['type'])
        sheet['V' + str(current_row)] = v['length']
        sheet['W' + str(current_row)] = 1 if v['required'] else 0
        sheet['X' + str(current_row)] = v['description']

        current_row = current_row + 1

    xfile.save(filename)


def generate_api_template_file(program, outputfile):

    if not program:
        return '\033[91m' + "Error: Program name is missing" + '\033[0m'

    if not outputfile:
        return '\033[91m' + "Error: Output filename is missing" + '\033[0m'

    api_name = program
    filename = outputfile
    if(not outputfile.endswith('.xlsx')):
        filename = filename + '.xlsx'

    api_info = getAPIFile(api_name)

    if api_info is not None:
        #print(api_info)
        params = getParametersList(api_info[1])
        copyTemplateFile(filename)
        updateSheetWithData(filename, api_info[0], params)
        print(bcolors.OKGREEN + "File generated successfully" + bcolors.ENDC)
        return True
    else:
        print(bcolors.FAIL +
              "Error: API specifications file not found in directory 'api-files'. Please make sure that specifications file exits" + bcolors.ENDC)
    return False

"""
def getAPIProgramNames():
    files = os.listdir(apiDirPath)
    for filename in files:
        file_path = os.path.join(apiDirPath, filename)
        with open(file_path) as json_file:
            data = json.load(json_file)
            file_api_name = data['info']['title'].split()[0]
            print("\'" + file_api_name + "\'" +',')
"""



from urllib.parse import urlparse

def url_change(url):
    
   if url.find("ionapi") > 0:
      path = urlparse(url).path
      result = "https://mingle-sso.eu1.inforcloudsuite.com" 

      return result
   else:
      return url


from urllib.parse import urlparse

def url_change(url):
    if "ionapi" in url:
        url = 'https://mingle-sso.eu1.inforcloudsuite.com/BVB_DEV/'
        return url 
    else:
        return url

url = 'https://mingle-ionapi.eu1.inforcloudsuite.com/BVB_DEV/'
if "ionapi" in url:
    path = urlparse(url).path
    
    result = "https://mingle-sso.eu1.inforcloudsuite.com" + path
    print("Original: ", url)
    print("Extracted: ", result)


